@@ -3,7 +3,7 @@ package Crypt::JWT;
 use strict;
 use warnings;
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(decode_jwt encode_jwt)] );
@@ -108,13 +108,15 @@ sub _add_claims {
 sub _verify_claims {
   my ($payload, %args) = @_;
 
+  return if $args{ignore_claims};
+
   my $leeway = $args{leeway} || 0;
   my $now = time;
 
   ### iat
   if(defined $payload->{iat}) {
     if (!defined $args{verify_iat} || $args{verify_iat}==1) {
-      croak "JWT: iat claim check failed" if $payload->{iat} - $leeway < $now;
+      croak "JWT: iat claim check failed ($payload->{iat}/$leeway vs. $now)" if $payload->{iat} - $leeway > $now;
     }
   }
   elsif ($args{verify_iat} && $args{verify_iat}==1) {
@@ -124,7 +126,7 @@ sub _verify_claims {
   ### nbf
   if(defined $payload->{nbf}) {
     if (!defined $args{verify_nbf} || $args{verify_nbf}==1) {
-      croak "JWT: nbf claim check failed" if $payload->{nbf} - $leeway < $now;
+      croak "JWT: nbf claim check failed ($payload->{nbf}/$leeway vs. $now)" if $payload->{nbf} - $leeway > $now;
     }
   }
   elsif ($args{verify_nbf} && $args{verify_nbf}==1) {
@@ -134,7 +136,7 @@ sub _verify_claims {
   ### exp
   if(defined $payload->{exp}) {
     if (!defined $args{verify_exp} || $args{verify_exp}==1) {
-      croak "JWT: exp claim check failed" if $payload->{exp} + $leeway > $now;
+      croak "JWT: exp claim check failed ($payload->{exp}/$leeway vs. $now)" if $payload->{exp} + $leeway < $now;
     }
   }
   elsif ($args{verify_exp} && $args{verify_exp}==1) {
@@ -879,6 +881,12 @@ C<undef> (default) - 'exp' claim must be valid if present
 
 Tolerance in seconds related to C<verify_exp>, C<verify_nbf>, C<verify_iat>. Default is C<0>.
 
+=item ignore_claims
+
+C<1> - do not check claims (iat, exp, nbf, iss, aud, sub, jti), B<BEWARE: DANGEROUS, UNSECURE!!!>
+
+C<0> (default) - check claims
+
 =back
 
 =head2 encode_jwt
@@ -1014,7 +1022,7 @@ C<0> (default) - do not allow JWS with C<none> 'alg' header value
 
 This optional parameter may contain a HASH ref with items that will be added to JWT header.
 
-If you want to use PBES2-based 'alg' like C<PBES2-HS512+A256KW> you can set PBES2 salt len (p2s) in bytes and 
+If you want to use PBES2-based 'alg' like C<PBES2-HS512+A256KW> you can set PBES2 salt len (p2s) in bytes and
 iteration count (p2c) via C<extra_headers> like this:
 
  my $token = encode_jwt(payload=>$p, key=>$k, alg=>'PBES2-HS512+A256KW', extra_headers=>{p2c=8000, p2s=>32});
